@@ -1,4 +1,4 @@
-#' Print \code{ontology_index} object.
+#' Print \code{ontology_index} object
 #'
 #' @param x \code{ontology_index} object.
 #' @param ... Unused parameters.
@@ -20,5 +20,14 @@ print.ontology_index <- function(x, ...) {
 	if (length(roots) > length(show_roots)) cat(" ... ", length(roots)-length(show_roots), " more\n", sep="")
 }
 
-
+#' Case \code{ontology_index} object to \code{data.frame}
+#'
+#' @param x \code{ontology_index} object.
+#' @param ... Arguments pass to \code{as.data.frame}. 
+#' @return \code{data.frame} containing information about an ontology, rows corresponding to terms and columns to properties.
+#' @method as.data.frame ontology_index
+#' @export
+as.data.frame.ontology_index <- function(x, ...) {
+	as.data.frame(lapply(x, function(col) if (is.list(col)) sapply(col, paste0, collapse="; ") else col), stringsAsFactors=FALSE, check.names=FALSE, ...)
+}
 
